/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"
#include "shiplog.h"

/* individual library stuff */
int nlua_loadShiplog( nlua_env *env );
